## CHANGELOG

### 0.9.0 - 2019-10-23

 - Improve string and integer schemas

 - Improve mypy

### 0.8.1 - 2019-10-22

 - Add package typing support

### 0.8.0 - 2019-10-02

 - Pin orjson version

 - Fix typo on readme

 - Improve jsondaora decorator

 - Add devtools git submodule

### 0.7.0 - 2019-09-27

 - Create changelog manager
